@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2002, 2025, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License, version 2.0, as published by
  * the Free Software Foundation.
@@ -304,7 +304,7 @@ public class CallableStatementRegressionTest extends BaseTestCase {
             assertEquals(Types.INTEGER, cStmt.getParameterMetaData().getParameterType(1));
             java.sql.DatabaseMetaData dbmd = this.conn.getMetaData();
 
-            this.rs = ((com.mysql.cj.jdbc.DatabaseMetaData) dbmd).getFunctionColumns(this.conn.getCatalog(), null, "testBug10310", "%");
+            this.rs = dbmd.getFunctionColumns(this.conn.getCatalog(), null, "testBug10310", "%");
             ResultSetMetaData rsmd = this.rs.getMetaData();
 
             assertEquals(17, rsmd.getColumnCount());
@@ -1386,7 +1386,7 @@ public class CallableStatementRegressionTest extends BaseTestCase {
                         cstmt.getString(2);
                         return null;
                     });
-                    assertThrows(testCase, SQLException.class, "Column '@com_mysql_jdbc_outparam_oparam' not found\\.", () -> {
+                    assertThrows(testCase, SQLException.class, "Column '@`com_mysql_jdbc_outparam_oparam`' not found\\.", () -> {
                         cstmt.getString("oparam");
                         return null;
                     });
@@ -1646,11 +1646,12 @@ public class CallableStatementRegressionTest extends BaseTestCase {
                 "(INOUT p1 VARCHAR(20), IN p2 VARCHAR(20), IN pX INT, OUT p3 VARCHAR(20)) BEGIN SELECT CONCAT(p1, p2) INTO p1; SELECT CONCAT(p1, p2) INTO p3;  END");
         createFunction("testBug73774_2", "(p1 VARCHAR(20), pX INT, p2 VARCHAR(20)) RETURNS VARCHAR(40) DETERMINISTIC RETURN CONCAT(p1, p2)");
 
+        boolean useIS = false;
         boolean getPRF = false;
         boolean useSPS = false;
 
         do {
-            final String testCase = String.format("Case [getPRF: %s, useSPS: %s]", getPRF ? "Y" : "N", useSPS ? "Y" : "N");
+            final String testCase = String.format("Case [useIS: %s, getPRF: %s, useSPS: %s]", useIS ? "Y" : "N", getPRF ? "Y" : "N", useSPS ? "Y" : "N");
 
             Properties props = new Properties();
             props.setProperty("getProceduresReturnsFunctions", Boolean.toString(getPRF));
@@ -1800,7 +1801,7 @@ public class CallableStatementRegressionTest extends BaseTestCase {
             });
             cstmtF2.close();
             testConn.close();
-        } while ((useSPS = !useSPS) || (getPRF = !getPRF));
+        } while ((useIS = !useIS) || (useSPS = !useSPS) || (getPRF = !getPRF));
     }
 
     /**
@@ -1954,4 +1955,51 @@ public class CallableStatementRegressionTest extends BaseTestCase {
         assertEquals(11, isProcedure ? testCstmt.getInt("c") : testCstmt.getInt(1));
     }
 
+    /**
+     * Tests fix for Bug#19829452, PARAMETER INDEX VALIDATION NOT PROPER IN CALLABLESTATEMENT.
+     *
+     * @throws Exception
+     */
+    @Test
+    public void testBug19829452() throws Exception {
+        createProcedure("testBug19829452", "(IN a VARCHAR(10), INOUT b VARCHAR(10)) BEGIN SET b = 'data'; END");
+        CallableStatement testCstmt = this.conn.prepareCall("{ CALL testBug19829452(?, ?) }");
+        testCstmt.setString(1, "a");
+        testCstmt.setString(2, "b");
+        testCstmt.registerOutParameter(2, java.sql.Types.VARCHAR);
+        testCstmt.execute();
+        assertThrows(SQLException.class, () -> testCstmt.getString(0));
+    }
+
+    /**
+     * Tests fix for Bug#19857207, EXECUTE ON CALLABLESTATEMENT RESULTS IN ARRAYINDEXOUTOFBOUNDSEXCEPTION.
+     *
+     * @throws Exception
+     */
+    @Test
+    public void testBug19857207() throws Exception {
+        createProcedure("testBug19857207", "(IN a VARCHAR(10),INOUT b VARCHAR(10)) BEGIN SET b = 'data'; END");
+        CallableStatement testCstmt = this.conn.prepareCall("{ CALL testBug19857207('a', ?) }");
+        testCstmt.setString(1, "b");
+        testCstmt.registerOutParameter(1, java.sql.Types.VARCHAR);
+        testCstmt.execute();
+        assertEquals("data", testCstmt.getString(1));
+    }
+
+    /**
+     * Tests fix for Bug#20279671, PROCEDURE EXECUTION FAILS WHEN THE PARAMETER NAME CONTAINS ESCAPE CHARACTER.
+     *
+     * @throws Exception
+     */
+    @Test
+    void testBug20279671() throws Exception {
+        createProcedure("testbug20279671p", "(IN `p``1` INT, INOUT `p``2` INT) BEGIN Set `p``2` = `p``1` +`p``2`; END");
+        CallableStatement testCstmt = this.conn.prepareCall("{ CALL testbug20279671p(?, ?) }");
+        testCstmt.setInt(1, 1);
+        testCstmt.setInt(2, 2);
+        testCstmt.registerOutParameter(2, java.sql.Types.INTEGER);
+        testCstmt.execute();
+        assertEquals(3, testCstmt.getInt("p`2"));
+    }
+
 }
